@@ -61,8 +61,10 @@ class DataFrameSummary(object):
 
         raise KeyError(column)
     @classmethod
-    def _get_pairplot(self,data,continuous=[],categorical=[]):
+    def _get_pairplot(self,data=None,continuous=[],categorical=[]):
         print("Hello!",continuous)
+        if(data==None):
+            return "Send the Data Please"
         for i in data.columns:
             if(data[i].nunique/data.shape[0])*100>20:
                continuous.append(i)
